Package 'nycmaps'

Title: A collection of sf objects and related tibbles for making maps of New York City
Description: Simple features boundary files for New York City across various administrative and Census geographies.
Authors: Kieran Healy [aut, cre] (ORCID: <https://orcid.org/0000-0001-9114-981X>)
Maintainer: Kieran Healy <[email protected]>
License: MIT + file LICENSE
Version: 0.0.3.9000
Built: 2026-06-04 06:43:29 UTC
Source: https://github.com/kjhealy/nycmaps

Help Index


Drop Staten Island from a map

Description

Crop a spatial object so that Staten Island is removed. The map is first clipped on the west, just beyond the easternmost point of the Staten Island polygon, and then clipped on the south, just below the southernmost tip of Breezy Point (the southern tip of Queens).

Usage

drop_staten_island(x, buffer = 10)

Arguments

x

An sf object or a terra::SpatRaster. Must have a defined CRS.

buffer

Numeric scalar giving the offset, in the map units of x's CRS, used to place the cut "just beyond" the Staten Island and Breezy Point extremes. Defaults to 10 (feet when x uses EPSG:2263, the default for maps in this package).

Details

This is an S3 generic with methods for sf objects and terra::SpatRaster rasters.

Value

An object of the same class as x, cropped to exclude Staten Island.

Examples

drop_staten_island(nyc_boros_sf)

NYC Atomic Polygons

Description

Atomic Polygons are the smallest geographic units created by NYC Planning that result from the intersection of various administrative and political boundaries. These polygons are the building blocks for aggregating data across different geographic hierarchies.

Usage

nyc_atomic_polygons_sf

Format

nyc_atomic_polygons_sf

A simple feature collection with 69,690 rows and 30 columns:

borough

Borough code (1-5)

censusbloc

2020 Census block number

censusbl_1

Census block suffix

censustrac

2020 Census tract number

censusbl_2

2010 Census block number

censusbl_3

2010 Census block suffix

censustr_1

2020 Census tract number (alternate)

censustr_2

2010 Census tract number

admin_fire

Fire company administrative unit

water_flag

Water area flag indicator

assemdist

State Assembly district

electdist

Election district

schooldist

School district

commdist

Community district

sb1_volume

Section book 1 volume

sb1_page

Section book 1 page

sb2_volume

Section book 2 volume

sb2_page

Section book 2 page

sb3_volume

Section book 3 volume

sb3_page

Section book 3 page

atomicid

Unique atomic polygon identifier

atomic_num

Atomic polygon number

hurricane

Hurricane evacuation zone

censustr_3

2020 Census tract (alternate)

censusbl_4

2020 Census block (alternate)

censusbl_5

2020 Census block suffix (alternate)

commercial

Commercial overlay zone

shape_leng

Shape length in feet

shape_area

Shape area in square feet

geometry

MULTIPOLYGON geometry

Details

NYC Atomic Polygons, Release: 25C, August 2025. Produced by NYC Planning Department. These polygons are created by overlaying multiple administrative and political boundaries to create the finest level of geographic detail. They can be used to aggregate data to any of the boundary types they contain.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City borough names

Description

Borough and county names and code.

Usage

nyc_boros

Format

nyc_boros

A data frame with 5 rows and 5 columns:

boro_code

City borough code. (Numeric)

boro_name

Borough name

county_name

County_Name County

short_county_name

County_Name

long_county_name

County_Name County, New York

Details

DETAILS

Author(s)

Kieran Healy

<SOURCE_URL>


New York City borough boundaries

Description

Clipped to shoreline. EPSG:2263, NAD83 / New York Long Island (ftUS). An sf object.

Usage

nyc_boros_sf

Format

nyc_boros_sf

A data frame with 5 rows and 5 columns:

boro_code

Numeric borough code

boro_name

Borough Name

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Borough boundaries for NYC, clipped to shoreline. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Community District Tabulation Areas 2020

Description

Simple feature collection of NYC Community District Tabulation Areas (CDTAs) from 2020. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_cdtas_2020_sf

Format

nyc_cdtas_2020_sf

A simple feature collection with 71 rows and 9 columns:

boro_code

Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

boro_name

Borough name

county_fips

Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)

cdta2020

Unique alphanumeric identifier representing Community District Tabulation Areas (CDTA)

cdta_name

Full name of CDTA

cdta_type

Differentiates between CDTAs which represent a community district (CD) or a joint interest area

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Community District Tabulation Areas (CDTAs) are approximations of NYC community districts created from census tracts. They represent areas outside of community districts as joint interest areas. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


NYC Census Block Relationships 2020

Description

Relationship table linking 2020 census blocks to census tracts, Neighborhood Tabulation Areas (NTAs), and Community District Tabulation Areas (CDTAs).

Usage

nyc_census_block_relationships_2020_df

Format

nyc_census_block_relationships_2020_df

A data frame with 37984 rows and 17 columns:

geoid

Unique identifier for 2020 census blocks (15-digit FIPS code: 3-digit county + 6-digit census tract + 4-digit block)

county_fips

Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)

boro_code

Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

boro_name

Borough name

bctcb2020

Unique identifier for 2020 census blocks (BoroCode + census tract + census block)

cb2020

2020 census block number

cb_label

Census block identifier with label

boro_ct2020

Unique identifier for 2020 census tracts (BoroCode + CT2020)

ct2020

2020 census tract number (6-digit)

ct_label

Census tract identifier

nta_code

Unique alphanumeric identifier for each Neighborhood Tabulation Area (6 characters)

nta_type

NTA type differentiating residential and non-residential geographies

nta_name

Full NTA name

nta_abbrev

Shortened version of NTA name

cdta_code

Unique alphanumeric identifier for Community District Tabulation Areas (4 characters)

cdta_type

Differentiates between CDTAs representing a community district (CD) or joint interest area

cdta_name

Full name of CDTA

Details

This table provides the hierarchical relationships between census blocks (the smallest census geography) and larger geographic units including census tracts, NTAs, and CDTAs. Produced by NYC Planning Department from 2020 Census data.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Census Blocks 2000

Description

Simple feature collection of NYC Census Blocks from 2000. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_census_blocks_2000_sf

Format

nyc_census_blocks_2000_sf

A simple feature collection with 36721 rows and 8 columns:

bctcb2000

Unique identifier for 2000 census blocks (BoroCode + CT2000 + CB2000)

cb2000

2000 census block number (4-digit)

boro_code

Borough code as character (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

boro_name

Borough name

ct2000

2000 census tract number (6-digit)

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Census blocks are the smallest geographic units used by the U.S. Census Bureau for tabulation of 100-percent data. Produced by NYC Planning Department. Release: 21B.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Census Blocks 2010

Description

Simple feature collection of NYC Census Blocks from 2010. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_census_blocks_2010_sf

Format

nyc_census_blocks_2010_sf

A simple feature collection with 38797 rows and 8 columns:

cb2010

2010 census block number (4-digit)

boro_code

Borough code as character (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

boro_name

Borough name

ct2010

2010 census tract number (6-digit)

bctcb2010

Unique identifier for 2010 census blocks (BoroCode + CT2010 + CB2010)

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Census blocks are the smallest geographic units used by the U.S. Census Bureau for tabulation of 100-percent data. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Census Blocks 2020

Description

Simple feature collection of NYC Census Blocks from 2020. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_census_blocks_2020_sf

Format

nyc_census_blocks_2020_sf

A simple feature collection with 37588 rows and 9 columns:

cb2020

2020 census block number (4-digit)

boro_code

Borough code as character (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

boro_name

Borough name

ct2020

2020 census tract number (6-digit)

bctcb2020

Unique identifier for 2020 census blocks (BoroCode + CT2020 + CB2020)

geoid

Unique identifier for 2020 census blocks (15-digit FIPS code)

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Census blocks are the smallest geographic units used by the U.S. Census Bureau for tabulation of 100-percent data. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


NYC Census Tract Relationships 2020

Description

Relationship table linking 2020 census tracts to Neighborhood Tabulation Areas (NTAs) and Community District Tabulation Areas (CDTAs).

Usage

nyc_census_tract_relationships_2020_df

Format

nyc_census_tract_relationships_2020_df

A data frame with 2327 rows and 14 columns:

geoid

Unique identifier for 2020 census tracts (11-digit FIPS code: 3-digit county + 6-digit census tract)

county_fips

Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)

boro_code

Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

boro_name

Borough name

boro_ct2020

Unique identifier for 2020 census tracts (BoroCode + CT2020)

ct2020

2020 census tract number (6-digit)

ct_label

Census tract identifier

nta_code

Unique alphanumeric identifier for each Neighborhood Tabulation Area (6 characters)

nta_type

NTA type differentiating residential and non-residential geographies

nta_name

Full NTA name

nta_abbrev

Shortened version of NTA name

cdta_code

Unique alphanumeric identifier for Community District Tabulation Areas (4 characters)

cdta_type

Differentiates between CDTAs representing a community district (CD) or joint interest area

cdta_name

Full name of CDTA

Details

This table provides the relationships between census tracts and larger geographic aggregations including NTAs and CDTAs. Produced by NYC Planning Department from 2020 Census data.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Census Tracts 2000

Description

Simple feature collection of NYC Census Tracts from 2000. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_census_tracts_2000_sf

Format

nyc_census_tracts_2000_sf

A simple feature collection with 2216 rows and 12 columns:

ct_label

Census tract identifier

boro_code

Borough code as character (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

boro_name

Borough name

ct2000

2000 census tract number (6-digit)

boro_ct2000

Unique identifier for 2000 census tracts (BoroCode + CT2000)

cd_eligibil

Community District eligibility (E=Eligible, I=Ineligible)

nta_code

Unique alphanumeric identifier for each Neighborhood Tabulation Area

ntan_ame

Neighborhood Tabulation Area name

puma

Public Use Microdata Area identifier

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Census tracts are small, relatively permanent statistical subdivisions of a county. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Census Tracts 2010

Description

Simple feature collection of NYC Census Tracts from 2010. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_census_tracts_2010_sf

Format

nyc_census_tracts_2010_sf

A simple feature collection with 2165 rows and 12 columns:

ct_label

Census tract identifier

boro_code

Borough code as character (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

boro_name

Borough name

ct2010

2010 census tract number (6-digit)

boro_ct2010

Unique identifier for 2010 census tracts (BoroCode + CT2010)

cd_eligibil

Community District eligibility (E=Eligible, I=Ineligible)

nta_code

Unique alphanumeric identifier for each Neighborhood Tabulation Area

nta_name

Neighborhood Tabulation Area name

puma

Public Use Microdata Area identifier

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Census tracts are small, relatively permanent statistical subdivisions of a county. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Census Tracts 2020

Description

Simple feature collection of NYC Census Tracts from 2020. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_census_tracts_2020_sf

Format

nyc_census_tracts_2020_sf

A simple feature collection with 2325 rows and 15 columns:

ct_label

Census tract identifier

boro_code

Borough code as character (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

boro_name

Borough name

ct2020

2020 census tract number (6-digit)

boro_ct2020

Unique identifier for 2020 census tracts (BoroCode + CT2020)

cd_eligibil

Community District eligibility (E=Eligible, I=Ineligible)

nta_name

Full Neighborhood Tabulation Area name

nta2020

Unique alphanumeric identifier for each 2020 Neighborhood Tabulation Area

cdta2020

Unique alphanumeric identifier representing Community District Tabulation Areas (CDTA)

cdtaname

Full name of CDTA

geoid

Unique identifier for 2020 census tracts (11-digit FIPS code)

puma

Public Use Microdata Area identifier

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Census tracts are small, relatively permanent statistical subdivisions of a county. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Council Districts

Description

Simple feature collection of NYC City Council Districts. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_city_council_districts_sf

Format

nyc_city_council_districts_sf

A simple feature collection with 51 rows and 4 columns:

coun_dist

City Council district number

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Boundaries of NYC City Council Districts. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Congressional Districts

Description

Simple feature collection of NYC Congressional Districts. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_congressional_districts_sf

Format

nyc_congressional_districts_sf

A simple feature collection with 13 rows and 4 columns:

cong_dist

Congressional district number

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Boundaries of NYC Congressional Districts. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


NYC Census Tract to City Council District Relationships 2023

Description

Relationship table linking 2020 census tracts to 2023 City Council Districts.

Usage

nyc_ct_ccd_relationships_2023_df

Format

nyc_ct_ccd_relationships_2023_df

A data frame with 2327 rows and 8 columns:

geoid

Unique identifier for 2020 census tracts (11-digit FIPS code: 3-digit county + 6-digit census tract)

county_fips

Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)

boro_code

Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

boro_name

Borough name

boro_ct2020

Unique identifier for 2020 census tracts (BoroCode + CT2020)

ct2020

2020 census tract number (6-digit)

ct_label

Census tract identifier

ccd2023

2023 City Council District number

Details

This crosswalk table links census tracts to City Council Districts, allowing census data to be aggregated to City Council District boundaries. Produced by NYC Planning Department.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


NYC Census Tract Population Proportions 2010 to 2020

Description

Proportions of 2010 census tract populations that fall within 2020 census tract boundaries. This table is useful for allocating data from 2010 census tracts to 2020 census tracts.

Usage

nyc_ct_pop_proportion_2010_2020_df

Format

nyc_ct_pop_proportion_2010_2020_df

A data frame with 2416 rows and 8 columns:

boro_code

Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

county_fips

Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)

boro_name

Borough name

bct2020

Unique identifier for 2020 census tracts (BoroCode + CT2020)

fipsct2020

Alternate unique identifier for 2020 census tracts (CountyFIPS + CT2020)

bct2010

Unique identifier for 2010 census tracts (BoroCode + CT2010)

fipsct2010

Alternate unique identifier for 2010 census tracts (CountyFIPS + CT2010)

prptn10t20

Proportion of the 2010 census tract population that falls within 2020 census tract boundaries

Details

When census tract boundaries change between decades, this crosswalk table allows allocation of population-based statistics from one set of boundaries to another. Produced by NYC Planning Department from 2020 Census data.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Election Precincts

Description

Simple feature collection of NYC Election Precincts. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_election_precincts_sf

Format

nyc_election_precincts_sf

A simple feature collection with 4264 rows and 4 columns:

elect_dist

Election district identifier

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Boundaries of NYC Election Districts (also known as Election Precincts). Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Fire Companies

Description

Simple feature collection of NYC Fire Companies. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_fire_companies_sf

Format

nyc_fire_companies_sf

A simple feature collection with 348 rows and 7 columns:

fire_co_type

Fire company type (E=Engine, L=Ladder, Q=Squad)

fire_co_num

Fire company number

fire_bn

Fire battalion number

fire_div

Fire division number

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Boundaries of NYC Fire Companies. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Municipal Court Districts

Description

Simple feature collection of NYC Municipal Court Districts. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_municipal_court_districts_sf

Format

nyc_municipal_court_districts_sf

A simple feature collection with 28 rows and 6 columns:

boro_code

Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

boro_name

Borough name

muni_court

Municipal court district identifier

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Boundaries of NYC Municipal Court Districts. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Neighborhood Tabulation Areas 2010

Description

Simple feature collection of NYC Neighborhood Tabulation Areas from 2010. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_nta10_sf

Format

nyc_nta10_sf

A simple feature collection with 195 rows and 8 columns:

boro_code

Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

boro_name

Borough name

county_fips

Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)

nta_code

Unique alphanumeric identifier for each Neighborhood Tabulation Area

nta_name

Full NTA name

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Neighborhood Tabulation Areas (NTAs) are aggregations of census tracts that are subsets of New York City's 55 Public Use Microdata Areas (PUMAs). Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Neighborhood Tabulation Areas 2020

Description

Simple feature collection of NYC Neighborhood Tabulation Areas from 2020. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_nta20_sf

Format

nyc_nta20_sf

A simple feature collection with 262 rows and 12 columns:

boro_code

Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)

boro_name

Borough name

county_fips

Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)

nta2020

Unique alphanumeric identifier for each 2020 Neighborhood Tabulation Area

nta_name

Full NTA name

nta_abbrev

Shortened version of NTA name

nta_type

The NTA type differentiates between residential and various non-residential geographies

cdta2020

Unique alphanumeric identifier representing Community District Tabulation Areas (CDTA)

cdta_name

Full name of CDTA

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Neighborhood Tabulation Areas (NTAs) are aggregations of census tracts that are subsets of New York City's 55 Public Use Microdata Areas (PUMAs). Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Police Precincts

Description

Simple feature collection of NYC Police Precincts. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_police_precincts_sf

Format

nyc_police_precincts_sf

A simple feature collection with 78 rows and 4 columns:

precinct

Police precinct number

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Boundaries of NYC Police Precincts. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Public Use Microdata Areas 2010

Description

Simple feature collection of NYC Public Use Microdata Areas (PUMAs) from 2010. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_pumas_2010_sf

Format

nyc_pumas_2010_sf

A simple feature collection with 55 rows and 4 columns:

puma

Public Use Microdata Area identifier

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Public Use Microdata Areas (PUMAs) are non-overlapping, statistical geographic areas that partition each state or equivalent entity into geographic areas containing no fewer than 100,000 people each. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City Public Use Microdata Areas 2020

Description

Simple feature collection of NYC Public Use Microdata Areas (PUMAs) from 2020. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_pumas_2020_sf

Format

nyc_pumas_2020_sf

A simple feature collection with 55 rows and 4 columns:

puma

Public Use Microdata Area identifier

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Public Use Microdata Areas (PUMAs) are non-overlapping, statistical geographic areas that partition each state or equivalent entity into geographic areas containing no fewer than 100,000 people each. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City School Districts

Description

Simple feature collection of NYC School Districts. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_school_districts_sf

Format

nyc_school_districts_sf

A simple feature collection with 33 rows and 4 columns:

school_dist

School district number

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Boundaries of NYC School Districts. Produced by NYC Planning Department. Release: 25C, August 2025.

There are 32 school districts but the dataset contains 33 rows because District 10 has two entries. Most of District 10 is in the Bronx, but a small part of it consists of the piece of Manhattan that is not on the island of Manhattan: the Marble Hill neighborhood, which sits just across the Broadway Lift Bridge in the Bronx.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York City and locale shorelines

Description

Shoreline with parts of NJ and areas of Nassau County NY. sf object.

Usage

nyc_shoclip_sf

Format

nyc_shoclip_sf

A data frame with 7,426 rows and 16 columns:

SOURCE_ID

DESCRIPTION

SRC_DATE

DESCRIPTION

HOR_ACC

DESCRIPTION

INFORM

DESCRIPTION

ATTRIBUTE

DESCRIPTION

VER_DATE

DESCRIPTION

SRC_RESOLU

DESCRIPTION

DATA_SOURC

DESCRIPTION

EX_METH

DESCRIPTION

EXT_METH

DESCRIPTION

DAT_SET_CR

DESCRIPTION

SRC_CITA

DESCRIPTION

FIPS_ALPHA

DESCRIPTION

NOAA_Regio

DESCRIPTION

Shape_Leng

DESCRIPTION

geometry

DESCRIPTION

Details

Manually adapted from NYC with part of Jersey shoreline and eastern coastline outside of NYC boundaries. Edited from CUSP sheet.

Author(s)

Kieran Healy

https://nsde.ngs.noaa.gov


New York State Assembly Districts

Description

Simple feature collection of New York State Assembly Districts within NYC. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_state_assembly_districts_sf

Format

nyc_state_assembly_districts_sf

A simple feature collection with 65 rows and 4 columns:

assem_dist

State Assembly district number

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Boundaries of New York State Assembly Districts within NYC. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


New York State Senate Districts

Description

Simple feature collection of New York State Senate Districts within NYC. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_state_senate_districts_sf

Format

nyc_state_senate_districts_sf

A simple feature collection with 28 rows and 4 columns:

st_sen_dist

State Senate district number

shape_leng

Shape length

shape_area

Shape area

geometry

Multipolygon

Details

Boundaries of New York State Senate Districts within NYC. Produced by NYC Planning Department. Release: 25C, August 2025.

Author(s)

Kieran Healy

https://www.nyc.gov/content/planning/pages/resources#datasets


Simple Features collection of NYC Zip Codes

Description

Polygons of NYC zip codes along with 2019 ACS population estimate. EPSG:2263, NAD83 / New York Long Island (ftUS).

Usage

nyc_zip_sf

Format

nyc_zip_sf

A simple feature collection with 212 rows and 4 columns:

zip

Zip code (actually ZTCA)

zip_name

ZCTA5 name

pop

2019 ACS population estimage

geometry

Multipolydon for zip code area

Details

Geographies and population estimates from US Census Bureau, ACS 5-year estimates (2019). List of zip codes described in nyc_zips table elsewhere in this package.

Author(s)

Kieran Healy

See details.


NYC Zip Codes

Description

Table of New York City zip codes.

Usage

nyc_zips

Format

nyc_zips

A data frame with 255 rows and 7 columns:

zip

Zip Code

boro_name

Borough name

city_name

Nominal city (USPS designation)

county_name

County as 'Countyname County'

long_county_name

County as 'Countyname County, New York'

short_county_name

County as 'County'

po_name

Nominal post office (USPS designation)

Details

Full USPS Zip Code list from https://postalpro.usps.com/ZIP_Locale_Detail Initial regional subsetting via https://worldpopulationreview.com/zips/new-york

Author(s)

Kieran Healy

See details.