| Title: | A collection of sf objects and related tibbles for making maps of New York City |
|---|---|
| Description: | Simple features boundary files for New York City across various administrative and Census geographies. |
| Authors: | Kieran Healy [aut, cre] (ORCID: <https://orcid.org/0000-0001-9114-981X>) |
| Maintainer: | Kieran Healy <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.3.9000 |
| Built: | 2026-06-04 06:43:29 UTC |
| Source: | https://github.com/kjhealy/nycmaps |
Crop a spatial object so that Staten Island is removed. The map is first clipped on the west, just beyond the easternmost point of the Staten Island polygon, and then clipped on the south, just below the southernmost tip of Breezy Point (the southern tip of Queens).
drop_staten_island(x, buffer = 10)drop_staten_island(x, buffer = 10)
x |
An |
buffer |
Numeric scalar giving the offset, in the map units of
|
This is an S3 generic with methods for sf objects and
terra::SpatRaster rasters.
An object of the same class as x, cropped to exclude
Staten Island.
drop_staten_island(nyc_boros_sf)drop_staten_island(nyc_boros_sf)
Atomic Polygons are the smallest geographic units created by NYC Planning that result from the intersection of various administrative and political boundaries. These polygons are the building blocks for aggregating data across different geographic hierarchies.
nyc_atomic_polygons_sfnyc_atomic_polygons_sf
nyc_atomic_polygons_sfA simple feature collection with 69,690 rows and 30 columns:
Borough code (1-5)
2020 Census block number
Census block suffix
2020 Census tract number
2010 Census block number
2010 Census block suffix
2020 Census tract number (alternate)
2010 Census tract number
Fire company administrative unit
Water area flag indicator
State Assembly district
Election district
School district
Community district
Section book 1 volume
Section book 1 page
Section book 2 volume
Section book 2 page
Section book 3 volume
Section book 3 page
Unique atomic polygon identifier
Atomic polygon number
Hurricane evacuation zone
2020 Census tract (alternate)
2020 Census block (alternate)
2020 Census block suffix (alternate)
Commercial overlay zone
Shape length in feet
Shape area in square feet
MULTIPOLYGON geometry
NYC Atomic Polygons, Release: 25C, August 2025. Produced by NYC Planning Department. These polygons are created by overlaying multiple administrative and political boundaries to create the finest level of geographic detail. They can be used to aggregate data to any of the boundary types they contain.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Borough and county names and code.
nyc_borosnyc_boros
nyc_borosA data frame with 5 rows and 5 columns:
City borough code. (Numeric)
Borough name
County_Name County
County_Name
County_Name County, New York
DETAILS
Kieran Healy
<SOURCE_URL>
Clipped to shoreline. EPSG:2263, NAD83 / New York Long Island (ftUS). An sf object.
nyc_boros_sfnyc_boros_sf
nyc_boros_sfA data frame with 5 rows and 5 columns:
Numeric borough code
Borough Name
Shape length
Shape area
Multipolygon
Borough boundaries for NYC, clipped to shoreline. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Community District Tabulation Areas (CDTAs) from 2020. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_cdtas_2020_sfnyc_cdtas_2020_sf
nyc_cdtas_2020_sfA simple feature collection with 71 rows and 9 columns:
Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Borough name
Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)
Unique alphanumeric identifier representing Community District Tabulation Areas (CDTA)
Full name of CDTA
Differentiates between CDTAs which represent a community district (CD) or a joint interest area
Shape length
Shape area
Multipolygon
Community District Tabulation Areas (CDTAs) are approximations of NYC community districts created from census tracts. They represent areas outside of community districts as joint interest areas. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Relationship table linking 2020 census blocks to census tracts, Neighborhood Tabulation Areas (NTAs), and Community District Tabulation Areas (CDTAs).
nyc_census_block_relationships_2020_dfnyc_census_block_relationships_2020_df
nyc_census_block_relationships_2020_dfA data frame with 37984 rows and 17 columns:
Unique identifier for 2020 census blocks (15-digit FIPS code: 3-digit county + 6-digit census tract + 4-digit block)
Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)
Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Borough name
Unique identifier for 2020 census blocks (BoroCode + census tract + census block)
2020 census block number
Census block identifier with label
Unique identifier for 2020 census tracts (BoroCode + CT2020)
2020 census tract number (6-digit)
Census tract identifier
Unique alphanumeric identifier for each Neighborhood Tabulation Area (6 characters)
NTA type differentiating residential and non-residential geographies
Full NTA name
Shortened version of NTA name
Unique alphanumeric identifier for Community District Tabulation Areas (4 characters)
Differentiates between CDTAs representing a community district (CD) or joint interest area
Full name of CDTA
This table provides the hierarchical relationships between census blocks (the smallest census geography) and larger geographic units including census tracts, NTAs, and CDTAs. Produced by NYC Planning Department from 2020 Census data.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Census Blocks from 2000. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_census_blocks_2000_sfnyc_census_blocks_2000_sf
nyc_census_blocks_2000_sfA simple feature collection with 36721 rows and 8 columns:
Unique identifier for 2000 census blocks (BoroCode + CT2000 + CB2000)
2000 census block number (4-digit)
Borough code as character (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Borough name
2000 census tract number (6-digit)
Shape length
Shape area
Multipolygon
Census blocks are the smallest geographic units used by the U.S. Census Bureau for tabulation of 100-percent data. Produced by NYC Planning Department. Release: 21B.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Census Blocks from 2010. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_census_blocks_2010_sfnyc_census_blocks_2010_sf
nyc_census_blocks_2010_sfA simple feature collection with 38797 rows and 8 columns:
2010 census block number (4-digit)
Borough code as character (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Borough name
2010 census tract number (6-digit)
Unique identifier for 2010 census blocks (BoroCode + CT2010 + CB2010)
Shape length
Shape area
Multipolygon
Census blocks are the smallest geographic units used by the U.S. Census Bureau for tabulation of 100-percent data. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Census Blocks from 2020. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_census_blocks_2020_sfnyc_census_blocks_2020_sf
nyc_census_blocks_2020_sfA simple feature collection with 37588 rows and 9 columns:
2020 census block number (4-digit)
Borough code as character (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Borough name
2020 census tract number (6-digit)
Unique identifier for 2020 census blocks (BoroCode + CT2020 + CB2020)
Unique identifier for 2020 census blocks (15-digit FIPS code)
Shape length
Shape area
Multipolygon
Census blocks are the smallest geographic units used by the U.S. Census Bureau for tabulation of 100-percent data. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Relationship table linking 2020 census tracts to Neighborhood Tabulation Areas (NTAs) and Community District Tabulation Areas (CDTAs).
nyc_census_tract_relationships_2020_dfnyc_census_tract_relationships_2020_df
nyc_census_tract_relationships_2020_dfA data frame with 2327 rows and 14 columns:
Unique identifier for 2020 census tracts (11-digit FIPS code: 3-digit county + 6-digit census tract)
Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)
Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Borough name
Unique identifier for 2020 census tracts (BoroCode + CT2020)
2020 census tract number (6-digit)
Census tract identifier
Unique alphanumeric identifier for each Neighborhood Tabulation Area (6 characters)
NTA type differentiating residential and non-residential geographies
Full NTA name
Shortened version of NTA name
Unique alphanumeric identifier for Community District Tabulation Areas (4 characters)
Differentiates between CDTAs representing a community district (CD) or joint interest area
Full name of CDTA
This table provides the relationships between census tracts and larger geographic aggregations including NTAs and CDTAs. Produced by NYC Planning Department from 2020 Census data.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Census Tracts from 2000. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_census_tracts_2000_sfnyc_census_tracts_2000_sf
nyc_census_tracts_2000_sfA simple feature collection with 2216 rows and 12 columns:
Census tract identifier
Borough code as character (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Borough name
2000 census tract number (6-digit)
Unique identifier for 2000 census tracts (BoroCode + CT2000)
Community District eligibility (E=Eligible, I=Ineligible)
Unique alphanumeric identifier for each Neighborhood Tabulation Area
Neighborhood Tabulation Area name
Public Use Microdata Area identifier
Shape length
Shape area
Multipolygon
Census tracts are small, relatively permanent statistical subdivisions of a county. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Census Tracts from 2010. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_census_tracts_2010_sfnyc_census_tracts_2010_sf
nyc_census_tracts_2010_sfA simple feature collection with 2165 rows and 12 columns:
Census tract identifier
Borough code as character (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Borough name
2010 census tract number (6-digit)
Unique identifier for 2010 census tracts (BoroCode + CT2010)
Community District eligibility (E=Eligible, I=Ineligible)
Unique alphanumeric identifier for each Neighborhood Tabulation Area
Neighborhood Tabulation Area name
Public Use Microdata Area identifier
Shape length
Shape area
Multipolygon
Census tracts are small, relatively permanent statistical subdivisions of a county. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Census Tracts from 2020. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_census_tracts_2020_sfnyc_census_tracts_2020_sf
nyc_census_tracts_2020_sfA simple feature collection with 2325 rows and 15 columns:
Census tract identifier
Borough code as character (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Borough name
2020 census tract number (6-digit)
Unique identifier for 2020 census tracts (BoroCode + CT2020)
Community District eligibility (E=Eligible, I=Ineligible)
Full Neighborhood Tabulation Area name
Unique alphanumeric identifier for each 2020 Neighborhood Tabulation Area
Unique alphanumeric identifier representing Community District Tabulation Areas (CDTA)
Full name of CDTA
Unique identifier for 2020 census tracts (11-digit FIPS code)
Public Use Microdata Area identifier
Shape length
Shape area
Multipolygon
Census tracts are small, relatively permanent statistical subdivisions of a county. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC City Council Districts. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_city_council_districts_sfnyc_city_council_districts_sf
nyc_city_council_districts_sfA simple feature collection with 51 rows and 4 columns:
City Council district number
Shape length
Shape area
Multipolygon
Boundaries of NYC City Council Districts. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Congressional Districts. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_congressional_districts_sfnyc_congressional_districts_sf
nyc_congressional_districts_sfA simple feature collection with 13 rows and 4 columns:
Congressional district number
Shape length
Shape area
Multipolygon
Boundaries of NYC Congressional Districts. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Relationship table linking 2020 census tracts to 2023 City Council Districts.
nyc_ct_ccd_relationships_2023_dfnyc_ct_ccd_relationships_2023_df
nyc_ct_ccd_relationships_2023_dfA data frame with 2327 rows and 8 columns:
Unique identifier for 2020 census tracts (11-digit FIPS code: 3-digit county + 6-digit census tract)
Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)
Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Borough name
Unique identifier for 2020 census tracts (BoroCode + CT2020)
2020 census tract number (6-digit)
Census tract identifier
2023 City Council District number
This crosswalk table links census tracts to City Council Districts, allowing census data to be aggregated to City Council District boundaries. Produced by NYC Planning Department.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Proportions of 2010 census tract populations that fall within 2020 census tract boundaries. This table is useful for allocating data from 2010 census tracts to 2020 census tracts.
nyc_ct_pop_proportion_2010_2020_dfnyc_ct_pop_proportion_2010_2020_df
nyc_ct_pop_proportion_2010_2020_dfA data frame with 2416 rows and 8 columns:
Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)
Borough name
Unique identifier for 2020 census tracts (BoroCode + CT2020)
Alternate unique identifier for 2020 census tracts (CountyFIPS + CT2020)
Unique identifier for 2010 census tracts (BoroCode + CT2010)
Alternate unique identifier for 2010 census tracts (CountyFIPS + CT2010)
Proportion of the 2010 census tract population that falls within 2020 census tract boundaries
When census tract boundaries change between decades, this crosswalk table allows allocation of population-based statistics from one set of boundaries to another. Produced by NYC Planning Department from 2020 Census data.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Election Precincts. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_election_precincts_sfnyc_election_precincts_sf
nyc_election_precincts_sfA simple feature collection with 4264 rows and 4 columns:
Election district identifier
Shape length
Shape area
Multipolygon
Boundaries of NYC Election Districts (also known as Election Precincts). Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Fire Companies. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_fire_companies_sfnyc_fire_companies_sf
nyc_fire_companies_sfA simple feature collection with 348 rows and 7 columns:
Fire company type (E=Engine, L=Ladder, Q=Squad)
Fire company number
Fire battalion number
Fire division number
Shape length
Shape area
Multipolygon
Boundaries of NYC Fire Companies. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Municipal Court Districts. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_municipal_court_districts_sfnyc_municipal_court_districts_sf
nyc_municipal_court_districts_sfA simple feature collection with 28 rows and 6 columns:
Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Borough name
Municipal court district identifier
Shape length
Shape area
Multipolygon
Boundaries of NYC Municipal Court Districts. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Neighborhood Tabulation Areas from 2010. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_nta10_sfnyc_nta10_sf
nyc_nta10_sfA simple feature collection with 195 rows and 8 columns:
Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Borough name
Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)
Unique alphanumeric identifier for each Neighborhood Tabulation Area
Full NTA name
Shape length
Shape area
Multipolygon
Neighborhood Tabulation Areas (NTAs) are aggregations of census tracts that are subsets of New York City's 55 Public Use Microdata Areas (PUMAs). Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Neighborhood Tabulation Areas from 2020. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_nta20_sfnyc_nta20_sf
nyc_nta20_sfA simple feature collection with 262 rows and 12 columns:
Borough code (1=Manhattan, 2=Bronx, 3=Brooklyn, 4=Queens, 5=Staten Island)
Borough name
Federal unique ID for counties (005=Bronx, 047=Kings, 061=New York, 081=Queens, 085=Richmond)
Unique alphanumeric identifier for each 2020 Neighborhood Tabulation Area
Full NTA name
Shortened version of NTA name
The NTA type differentiates between residential and various non-residential geographies
Unique alphanumeric identifier representing Community District Tabulation Areas (CDTA)
Full name of CDTA
Shape length
Shape area
Multipolygon
Neighborhood Tabulation Areas (NTAs) are aggregations of census tracts that are subsets of New York City's 55 Public Use Microdata Areas (PUMAs). Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Police Precincts. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_police_precincts_sfnyc_police_precincts_sf
nyc_police_precincts_sfA simple feature collection with 78 rows and 4 columns:
Police precinct number
Shape length
Shape area
Multipolygon
Boundaries of NYC Police Precincts. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Public Use Microdata Areas (PUMAs) from 2010. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_pumas_2010_sfnyc_pumas_2010_sf
nyc_pumas_2010_sfA simple feature collection with 55 rows and 4 columns:
Public Use Microdata Area identifier
Shape length
Shape area
Multipolygon
Public Use Microdata Areas (PUMAs) are non-overlapping, statistical geographic areas that partition each state or equivalent entity into geographic areas containing no fewer than 100,000 people each. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC Public Use Microdata Areas (PUMAs) from 2020. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_pumas_2020_sfnyc_pumas_2020_sf
nyc_pumas_2020_sfA simple feature collection with 55 rows and 4 columns:
Public Use Microdata Area identifier
Shape length
Shape area
Multipolygon
Public Use Microdata Areas (PUMAs) are non-overlapping, statistical geographic areas that partition each state or equivalent entity into geographic areas containing no fewer than 100,000 people each. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of NYC School Districts. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_school_districts_sfnyc_school_districts_sf
nyc_school_districts_sfA simple feature collection with 33 rows and 4 columns:
School district number
Shape length
Shape area
Multipolygon
Boundaries of NYC School Districts. Produced by NYC Planning Department. Release: 25C, August 2025.
There are 32 school districts but the dataset contains 33 rows because District 10 has two entries. Most of District 10 is in the Bronx, but a small part of it consists of the piece of Manhattan that is not on the island of Manhattan: the Marble Hill neighborhood, which sits just across the Broadway Lift Bridge in the Bronx.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Shoreline with parts of NJ and areas of Nassau County NY. sf object.
nyc_shoclip_sfnyc_shoclip_sf
nyc_shoclip_sfA data frame with 7,426 rows and 16 columns:
DESCRIPTION
DESCRIPTION
DESCRIPTION
DESCRIPTION
DESCRIPTION
DESCRIPTION
DESCRIPTION
DESCRIPTION
DESCRIPTION
DESCRIPTION
DESCRIPTION
DESCRIPTION
DESCRIPTION
DESCRIPTION
DESCRIPTION
DESCRIPTION
Manually adapted from NYC with part of Jersey shoreline and eastern coastline outside of NYC boundaries. Edited from CUSP sheet.
Kieran Healy
Simple feature collection of New York State Assembly Districts within NYC. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_state_assembly_districts_sfnyc_state_assembly_districts_sf
nyc_state_assembly_districts_sfA simple feature collection with 65 rows and 4 columns:
State Assembly district number
Shape length
Shape area
Multipolygon
Boundaries of New York State Assembly Districts within NYC. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Simple feature collection of New York State Senate Districts within NYC. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_state_senate_districts_sfnyc_state_senate_districts_sf
nyc_state_senate_districts_sfA simple feature collection with 28 rows and 4 columns:
State Senate district number
Shape length
Shape area
Multipolygon
Boundaries of New York State Senate Districts within NYC. Produced by NYC Planning Department. Release: 25C, August 2025.
Kieran Healy
https://www.nyc.gov/content/planning/pages/resources#datasets
Polygons of NYC zip codes along with 2019 ACS population estimate. EPSG:2263, NAD83 / New York Long Island (ftUS).
nyc_zip_sfnyc_zip_sf
nyc_zip_sfA simple feature collection with 212 rows and 4 columns:
Zip code (actually ZTCA)
ZCTA5 name
2019 ACS population estimage
Multipolydon for zip code area
Geographies and population estimates from US Census Bureau, ACS 5-year estimates (2019).
List of zip codes described in nyc_zips table elsewhere in this package.
Kieran Healy
See details.
Table of New York City zip codes.
nyc_zipsnyc_zips
nyc_zipsA data frame with 255 rows and 7 columns:
Zip Code
Borough name
Nominal city (USPS designation)
County as 'Countyname County'
County as 'Countyname County, New York'
County as 'County'
Nominal post office (USPS designation)
Full USPS Zip Code list from https://postalpro.usps.com/ZIP_Locale_Detail Initial regional subsetting via https://worldpopulationreview.com/zips/new-york
Kieran Healy
See details.